<!--
SPDX-License-Identifier: CC-BY-SA-4.0
-->

# An open and affordable imaging platform for citizen oceanography

| | |
| --- | --- |
| CI/CD | [![CI - Test](https://github.com/PlanktoScope/PlanktoScope/actions/workflows/test.yml/badge.svg)](https://github.com/PlanktoScope/PlanktoScope/actions/workflows/test.yml) [![CD - Build](https://github.com/PlanktoScope/PlanktoScope/actions/workflows/build.yml/badge.svg)](https://github.com/PlanktoScope/PlanktoScope/actions/workflows/build.yml) |
| Package | [![PyPI - Version](https://img.shields.io/pypi/v/planktoscope.svg?logo=pypi&label=PyPI&logoColor=gold)](https://pypi.org/project/planktoscope/) [![PyPI - Python Version](https://img.shields.io/pypi/pyversions/planktoscope.svg?logo=python&label=Python&logoColor=gold)](https://pypi.org/project/planktoscope/) |
| Meta | [![Hatch project](https://img.shields.io/badge/%F0%9F%A5%9A-Hatch-4051b5.svg)](https://github.com/pypa/hatch) [![code style - black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black) [![types - Mypy](https://img.shields.io/badge/types-Mypy-blue.svg)](https://github.com/ambv/black) [![imports - isort](https://img.shields.io/badge/imports-isort-ef8336.svg)](https://github.com/pycqa/isort) [!

[License - GPL](https://img.shields.io/badge/license-GPL-blue.svg)](<https://spdx.org/licenses/>) |

<https://shields.io/badge/reuse-compliant-green>

![PlanktoScope Render](docs/images/readme/planktoscope_cad.webp)

![Plankton collage](docs/images/readme/plankton_collage.webp)

## What is this?

The PlanktoScope is an open-source, affordable imaging platform for citizen oceanography. It's built around a Raspberry Pi, a couple of HATs, some stepper motors and a few centimeters of silicon tubes. Its cost is at about $500 in parts.

The goal of the PlanktoScope is to allow citizen to engage in scientific programs, either at sea or onshore. You can use the PlanktoScope to image the different species of Plankton living in a body of water.

## Get the papers

The PlanktoScope has been described in a paper available on the [bioRxiv preprint server](https://www.biorxiv.org/content/10.1101/2020.04.23.056978v1). The first results of this program and its outline are also available as a [preprint](https://www.biorxiv.org/content/10.1101/2020.08.31.263442v1).

| [![PlanktoScope Preprint](docs/images/readme/planktoscope_pub.webp)](https://www.biorxiv.org/content/10.1101/2020.04.23.056978v1) | [![PlanktonPlanet Preprint](docs/images/readme/planktonplanet_pub.webp)](https://www.biorxiv.org/content/10.1101/2020.08.31.263442v1) |
| -------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------ |

## Key Features

- Image small animals and algae living in water
- Focus stage control
- Pump control
- Automatic image capture
- Automatic segmentation

## How do I build one?

You can access the complete documentation on [Read The Docs](https://planktonscope.readthedocs.io/).

## How do I get involved?

There are several ways to join the development effort, share your progress with your build or just ask for help.

We are using slack as a communication platform between interested parties. You can [request to join by filling this form](https://docs.google.com/forms/d/e/1FAIpQLSfcod-avpzWVmWj42_hW1v2mMSHm0DAGXHxVECFig2dnKHxGQ/viewform).

This repository is also a good way to get involved. Please fill in an issue if you witnessed a bug in the software or hardware. If you are able, you can also join the development effort. Look through the [issues opened](https://github.com/PlanktonPlanet/PlanktoScope/labels/good%20first%20issue) and choose one that piques your interest. Let us know you want to work on it in the comments, we may even be able to guide your beginnings around the code.

## License: Our work is fully open source

Depending on the material they cover, different licenses apply to the files of this repository.

If you make any change for your use, please fork this repository and publish your improvements. It will help others, and we can integrate those changes in this repository if needed.

Also, all licenses are contaminating, if you want to use any of this material for a project that you cannot open-source, please contact us using Slack so we can see what can be done to help you and your project.

## Hardware files

All hardware files and documentation (everything in the `hardware` directory) is released under a [CERN-OHL-S-2.0 license](https://ohwr.org/cern_ohl_s_v2.txt).

## Software source

The source code (everything in the directories `flows` and `scripts`) is released under a [GPL-3.0 license](https://www.gnu.org/licenses/gpl-3.0.en.html).

## Everything else (documentation, pictures, etc...)

Everything else is released under a [Creative Commons CC-BY-SA license](https://creativecommons.org/licenses/by-sa/4.0/).
